@@ -2,7 +2,7 @@ package Tinkerforge;
 
 # setting the module version
 use vars '$VERSION';
-our $VERSION = '2.1.17';
+our $VERSION = '2.1.18';
 
 =pod
 
@@ -14,7 +14,7 @@ Tinkerforge - Official Perl support for all Tinkerforge Bricks and Bricklets
 
 =head1 VERSION
 
-Version 2.1.17
+Version 2.1.18
 
 =head1 ABSTRACT
 
@@ -206,7 +206,7 @@ new device again.
             print "\nHumidity too high: ".$humidity/10.0." RH%\n";
         }
 
-        print "\nRecommended humiditiy for human comfort is 30 to 60 %RH.\n";
+        print "\nRecommended humidity for human comfort is 30 to 60 %RH.\n";
     }
 
     $ipcon->connect(&HOST, &PORT); # Connect to brickd
